.. neutron-lbaas-dashboard documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to neutron-lbaas-dashboard's documentation!
========================================================

.. warning::
   Neutron-lbaas-dashboard is now deprecated. Please see the FAQ: https://wiki.openstack.org/wiki/Neutron/LBaaS/Deprecation

Contents:

.. toctree::
   :maxdepth: 2

   readme
   installation
   usage
   contributing
   reference
